define('de_epages/sageone/ui/orderstatus',[
  'jquery',
  '$dict!../dictionary',
  'ep/ajax'
], function($, epDict) {

  /*
   * @dictionary       de_epages.sageone.dictionary
   *
   * @translation      {InternalErrorHelper}
   *                   {FailedToLoad}
   *                   {UnsupportedDestination}
   *                   {OrderAmountZero}
   *                   {UnsupportedCurrency}
   *                   {InvalidName}
   *                   {InvalidEmail}
   *                   {UnsupportedTaxRate}
   *                   {UnsupportedLineitem}
   *                   {UnexpectedErrorMessage}
   *                   {Error}
   *                   {OrderIsConflictedMessage}
   *                   {OrderIsConflicted}
   *                   {ExternalError}
   *                   {InternalError}
   *                   {Paid}
   *                   {Published}
   */

  return function (shopId, orderId){
    ep.ajax({
      data : {
        ViewAction : 'JSONSageOneShopStatus',
        ObjectID : shopId
      },
      type : 'get',
      dataType : 'json'
    }).done(function(jsonData) {
      readyShopStatus(jsonData, orderId);
    });
  };

  function readyShopStatus(jsonData, orderId) {
    if(jsonData.ShopStatus != "connected") {
      return undefined;
    } else {
      if(jsonData.SynchronizationStatus == "busy") {
        disableSyncButton();
      }

      showSyncButton();

      ep.ajax({
        data : {
          ViewAction : 'JSONSageOneOrderStatus',
          ObjectID : orderId
        },
        type : 'get',
        dataType : 'json'
      }).done(function(jsonData) {
        addDataToPage(jsonData);
      });

    }
  }

  function addDataToPage(jsonData){
    if(Object.keys(jsonData).length <= 0){
      return undefined;
    }

    switch (jsonData.Status.toLowerCase()) {
    case 'not_published':
      break;
    case 'published':
      showDeleteButton();
      disableSyncButton();
      var sageOrderStatus = epDict.translate('{Published}');
      var className = 'sage-one-published-status';
      printOrderStatus(jsonData, sageOrderStatus, className);
      break;
    case 'paid':
      showDeleteButton();
      disableSyncButton();
      var sageOrderStatus = epDict.translate('{Paid}');
      var className = 'sage-one-paid-status';
      printOrderStatus(jsonData, sageOrderStatus, className);
      break;
    case 'rejected_ep':
      var sageErrorType = epDict.translate('{InternalError}');
      var sageErrorMessage = buildErrorMessage(jsonData.StatusMessage);
      var className = 'sage-one-internal-error';
      printErrorMessageWithHelper(sageErrorType, sageErrorMessage, className);
      break;
    case 'rejected_sage':
      var sageErrorType = epDict.translate('{ExternalError}');
      var sageErrorMessage = jsonData.StatusMessage;
      var className = 'sage-one-external-error';
      printErrorMessage(sageErrorType, sageErrorMessage, className);
      break;
    case 'conflicted':
      var className = 'sage-one-internal-error-conflicted';
      var sageErrorType = epDict.translate('{OrderIsConflicted}');
      var sageErrorMessage = epDict.translate('{OrderIsConflictedMessage}');
      printErrorMessage(sageErrorType, sageErrorMessage, className);
      break;
    default:
      var sageErrorType = epDict.translate('{Error}');
      var sageErrorMessage = jsonData.StatusMessage;
      if(!sageErrorMessage){
        sageErrorMessage = epDict.translate('{UnexpectedErrorMessage}');
      }
      var className = 'sage-one-unknown-error';
      printErrorMessage(sageErrorType, sageErrorMessage, className);
      break;
    }
  }

  function buildErrorMessage (StatusMessage){
    var errorMessage = '';
    if(!StatusMessage){
      return epDict.translate('{UnexpectedErrorMessage}');
    }
    switch (StatusMessage.toLowerCase()) {
    case 'unsupported_lineitem':
      errorMessage = epDict.translate('{UnsupportedLineitem}');
      break;
    case 'no_tax':
      errorMessage = epDict.translate('{UnsupportedTaxRate}');
      break;
    case 'tax_rate_not_allowed':
      errorMessage = epDict.translate('{UnsupportedTaxRate}');
      break;
    case 'invalid_email':
      errorMessage = epDict.translate('{InvalidEmail}');
      break;
    case 'invalid_name':
      errorMessage = epDict.translate('{InvalidName}');
      break;
    case 'unsupported_currency':
      errorMessage = epDict.translate('{UnsupportedCurrency}');
      break;
    case 'order_amount_zero':
      errorMessage = epDict.translate('{OrderAmountZero}');
      break;
    case 'shipping_destination':
      errorMessage = epDict.translate('{UnsupportedDestination}');
      break;
    case 'failed_to_load':
      errorMessage = epDict.translate('{FailedToLoad}');
      break;
    default:
      errorMessage = StatusMessage;
      break;
    }
    return errorMessage;
  }

  function printOrderStatus(jsonData, sageOrderStatus, className){
    $('#InvoiceNumber').addClass(className);
    $('#InvoiceNumber').text(jsonData.SageInvoiceReference);
    $('#InvoiceStatus').addClass(className);
    $('#InvoiceStatus').text(sageOrderStatus);
    $('#LastStatusChange').addClass(className);
    $('#LastStatusChange').text(jsonData.LastStatusChange);
    activateInfoBox();
  }

  function printErrorMessage(sageErrorType, sageErrorMessage, className){
    $('#SageOneErrorType').addClass(className);
    $('#SageOneErrorType').text(sageErrorType);
    $('#SageOneErrorMessage').addClass(className);
    $('#SageOneErrorMessage').text(sageErrorMessage);
    activateErrorBox();
  }

  function printErrorMessageWithHelper(sageErrorType, sageErrorMessage, className){
    printErrorMessage(sageErrorType, sageErrorMessage, className);
    $('#SageOneErrorMessageHelper').addClass(className);
    $('#SageOneErrorMessageHelper').text(epDict.translate('{InternalErrorHelper}'));
  }

  function activateInfoBox () {
    $('#SageOneError').hide();
    $('#SageOneInfo').show();
  }

  function activateErrorBox () {
    $('#SageOneError').show();
    $('#SageOneInfo').hide();
  }

  function showSyncButton () {
    $('#SageOneSyncButton').show();
  }

  function disableSyncButton () {
    $('#SageOneSyncButton').addClass("Disabled");
    $('#SageOneSyncButton').children().removeAttr('href');
  }

  function showDeleteButton () {
    $('#SageOneDeleteButton').show();
  }

});
